@@ -29,8 +29,11 @@ const bool NO_GNUPLOT_LOG_FILES = false;
 const bool NO_REGRESSION_IMPORT = false;
 const bool NO_RESET = false;
 const bool NO_EXPORT_ONLY = false;
+const bool NO_EXTRACT_IMAGE_ONLY = false;
+const QString NO_EXTRACT_IMAGE_EXTENSION;
 const bool DEBUG_FLAG = false;
 const QStringList NO_LOAD_STARTUP_FILES;
+const QStringList NO_COMMAND_LINE;
 const QString STARTUP_DIG_LOWER_CASE ("/tmp/export_only.dig");
 const QString STARTUP_DIG_UPPER_CASE ("/tmp/export_only.DIG");
 const QStringList ONE_LOAD_STARTUP_FILE_LOWER_CASE (STARTUP_DIG_LOWER_CASE);
@@ -214,7 +217,10 @@ void TestExport::initTestCase ()
                                  NO_GNUPLOT_LOG_FILES,
                                  NO_RESET,
                                  NO_EXPORT_ONLY,
-                                 NO_LOAD_STARTUP_FILES);
+                                 NO_EXTRACT_IMAGE_ONLY,
+                                 NO_EXTRACT_IMAGE_EXTENSION,                                 
+                                 NO_LOAD_STARTUP_FILES,
+                                 NO_COMMAND_LINE);
 
   m_mainWindow->show ();
 }
